@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: libxml-sax
 version: 0.7.5
-id: libxml-sax-0.7.5-856c4308eb4976385a108d5795d6f217
-key: libxm_3XBrkSQp66KACjLfrAn1mr
+id: libxml-sax-0.7.5-5224794631ed64ec66d4738f6368afe2
+key: libxm_Kka5hy34modDHmU4xCPUNy
 license: MIT
 maintainer: jmillikin@gmail.com
 stability: experimental
@@ -18,15 +18,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/libxml-sax-0.7.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/libxml-sax-0.7.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/libxml-sax-0.7.5
-hs-libraries: HSlibxml-sax-0.7.5-3XBrkSQp66KACjLfrAn1mr
+hs-libraries: HSlibxml-sax-0.7.5-Kka5hy34modDHmU4xCPUNy
 extra-libraries:
     xml2 xml2
 include-dirs: /usr/include/libxml2
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
-    xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
 haddock-interfaces: /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
 haddock-html: /usr/share/doc/haskell-libxml-sax/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
